{% extends "django_msp_sms\base.html" %}
{% block title %}Preferencias de la Empresa{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}
{% endblock %}

{% block breadcrumb %}{{ block.super }}  <li class='active'> Preferencias de la Empresa</li>{% endblock %}
{% block content %}

{% if msg %}
<div class="alert alert-success" role="alert">
	<button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
	{{msg}}
</div>
{% endif %}

<form method="post" class="form-horizontal" action="" width="300px"  enctype='multipart/form-data'>{% csrf_token %}
	{{ form.errors }}
	<div class="page-header">
		<h1>Preferencias de la Empresa <button type="submit" class="btn"><i class="glyphicon glyphicon-floppy-disk"></i> Guardar</button>  </h1>
	</div>
		<div class="col-md-4 col-xs-2 col-sm-4">
			<div id="div_puntos">
				<label>Nombre de la Empresa</label>
				<a href="#" class="" data-toggle="tooltip" title="Este es el nombre de la empresa que aparecera en los mensajes" ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.empresa_nombre }}</div>
			</div>
		</div>
		<div class="col-md-4 col-xs-2 col-sm-4">
			<div id="div_puntos">
				<label>{{ form.informacion_extra.label }}</label>
				<a href="#" class="" data-toggle="tooltip" title="Información a agregar en todos los mensajes enviados, esta información se agregara al final de cada mensaje" ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.informacion_extra }}</div>
			</div>
		</div>
		<div class="col-md-4 col-xs-2 col-sm-4">
			<div id="div_puntos">
				<label>Numero de telefono por Default</label>
				<a href="#" class="" data-toggle="tooltip" title="Numero de telefono al cual se enviara un mensaje de texto en cada envio de mensajes masivos" ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.telefono_default }}</div>
			</div>
		</div>
		<div class="col-md-4 col-xs-2 col-sm-4">
			<div id="div_puntos">
				<label>Llave</label>
				<a href="#" class="" data-toggle="tooltip" title="Clave necesaria para el envio de mensajes en la aplicacion. contacte a a sus administrador" ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.apikey }}</div>
			</div>
		</div>
		<div class="col-md-8 col-xs-4 col-sm-8">
			<div>
		      {{ form.enviar_remisiones.label }} <br>
		      {{ form.enviar_remisiones }}
		    </div>
		    <div>
		      <label for="">{{ form.resumir_mensajes.label }} </label><br>
		      {{ form.resumir_mensajes }}
		    </div>
		    <div>
		      <label for="">{{ form.modo_pruebas.label }} </label><br>
		      {{ form.modo_pruebas }}
		    </div>
			<div id="div_puntos">
				<label>Monto Minimo</label>
				<a href="#" class="" data-toggle="tooltip" title="Monto minimo necesario para enviar un mensaje de saldo." ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.monto_minimo }}</div>
			</div>
		</div>
		<div class="col-md-8 col-xs-4 col-sm-8">
			<div id="div_puntos">
				<label>Dias por vencer para saldos automaticos</label>
				<a href="#" class="" data-toggle="tooltip" title="Dias faltantes para enviar recordatorio automatico" ><i class="glyphicon glyphicon-info-sign"></i></a>
				<div class="input-prepend input-append">{{ form.dias_atraso }}</div>
			</div>
		</div>
		<br style="clear:both;">
</form>
{% endblock %}