{% extends "django_msp_sms\base.html" %}
{% block title %}puntos{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}
{% endblock %}
{% block breadcrumb %}
  {{ block.super }} 
  <li><a href="/sms/clientes/"> Clientes </a></li> 
  <li class='active'> {{ cliente_nombre }}</li> 
{% endblock %}

{% block content %}
<form method="post" class="form-horizontal" action="" width="300px"  enctype='multipart/form-data'>{% csrf_token %}
  {{ form.errors }}
	<div class="page-header">
	  <h1>Cliente <small>{{ cliente_nombre }} </small> <button type="submit" class="btn"><i class="glyphicon glyphicon-download-alt"></i> Guardar</button>  </h1>
	</div>
	<!-- Nav tabs -->
	<ul class="nav nav-tabs" role="tablist">
	  <li class="active"><a href="#home" role="tab" data-toggle="tab">General</a></li>
	  <!-- <li><a href="#settings" role="tab" data-toggle="tab">Settings</a></li> -->
	</ul>
	<!-- Tab panes -->
	<div class="tab-content">
	  	<div class="tab-pane active" id="home">
	  		Ignorar Cliente Para el Envío de Mensajes de Texto <br> {{form.no_enviar_sms}}
		  	
		</div><!-- end panel-home -->
	</div>
</form>
{% endblock %}