{% extends "django_msp_sms\base.html" %}
{% block title %}SMS Masivo{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}

{% endblock %}

{% block breadcrumb %}{{ block.super }}{% endblock %}
{% block content %}
<h1 align="center"><strong>Envío de Mensajes de Texto </strong><small>v2.0.0</small></h1> 
<hr>
{% if modo_pruebas%}
<div class="alert alert-warning fade in">
	Aplicacion funcionando en modo PRUEBAS. <strong>Ningún mensaje será enviado realmente !!</strong>
</div>
{% endif %}
{% if error %}

<div class="alert alert-info" role="alert">
	<button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
	{{error}} <strong>{% if not error == 'Llave no Definida' %}<a href="/sms/inicializar">Aqui</a></strong> {% endif %}
</div>
{% else %}
<div class="alert alert-info" role="alert">
	<button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
	<strong>{{ creditos }}  Creditos disponibles {%if creditos == '0' %} (<a href="/sms/cargar_archivo/">Cargar archivo</a>){%endif%}</strong>  

</div>
{% endif %}



{% endblock %}