{% extends "django_msp_sms\base.html" %}
{% block title %}SMS por seleccion{% endblock %}

<!-- CSS Code -->
{% block style_css %}
{{ form.media.js }}
{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}

	{{ form.media.css }} 
	<script src="{{STATIC_URL}}js/django_msp_sms/saldos/sendcore.js?v=1.0.7"></script>
	<script src="{{STATIC_URL}}js/django_msp_sms/saldos/send_seleccion.js?v=1.0.7"></script>
	<script type="text/javascript">
    $(function () {
      $('#id_clientes').select2();
  });
</script>
{% endblock %}

{% block breadcrumb %}
  {{ block.super }} 
  <li class='active'> Saldos a Clientes Específicos</li> 
{% endblock %}

{% block content %}
<div >
	<h3><b>Envío de Saldos a Clientes Específicos</b>
	</h3>
</div>
<p class="text-info col-md-6 col-xs-12 cl-sm-12">Al pulsar el boton enviar se comenzara a enviar un mensaje por cada cliente seleccionado que cuente con un saldo que a la fecha sea mayor al monto minimo <small>(especificado en las preferencias)</small> <strong> a los clientes que no cuenten con teléfono celular válido registrado en <u>Teléfono 1</u> no se les enviara mensaje alguno. </strong>
<small>para seleccionar los clientes escribe el nombre de cada cliente en la caja de texto y seleccionalo de la lista</small>
</p>
<br style="clear:both;">
<div id="alert" class="alert alert-info fade in" role="alert">
	<!-- <button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button> -->
	<div id="alertContainer"></div>
</div> 
<div id="alert2" class="alert hidden alert-warning fade in" role="alert">
	<!-- <button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button> -->
	<div id="alertContainer2"></div>
</div>
<div class="progress">
  <div id="progreso" class="progress-bar progress-bar-striped active"  role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0%">
  </div>
</div>
<div align ="center" id="contenedor">
	<form method="POST" action="#" class="form-inline" enctype='multipart/form-data'>{% csrf_token %}
        {{ form.errors }}
		<div class="col-md-offset-3 col-md-3 col-xs-12 cl-sm-12">
			<label for="clientes_id">Clientes: </label>
			{{form.clientes}}<br>
		</div>
		<br style="clear:both">
		<a href="#" id="enviar_btn" class="btn btn-default" data-toggle="modal" data-target=".bs-example-modal-sm">
  		Enviar
		</a>
		<div class="modal fade bs-example-modal-sm" tabindex="-1" role="dialog" aria-labelledby="mySmallModalLabel" aria-hidden="true">
		  <div class="modal-dialog modal-sm">
		    <div class="modal-content">
		      <div class="modal-header">
          		<button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">×</span><span class="sr-only">Close</span></button>
          		<h4 class="modal-title" id="mySmallModalLabel">Seguro que quieres enviar los mensajes?</h4>
        	  </div>
        	  <div class="modal-body">
        	  	<button type="button" class="btn btn-default" data-dismiss="modal">Cancelar</button>
        	  	<a href="#" class="btn btn-default" id="btnEnviar-estadosCuenta" data-dismiss="modal">Si, estoy seguro</a>
        	  </div>
		    </div>
		  </div>
		</div>
		
	</form>
</div>
{% endblock %}