{% extends "django_msp_sms\base.html" %}
{% block title %}Inicio{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}
{% endblock %}

{% block breadcrumb %}{{ block.super }} {% endblock %}
{% block content %}
<h1 align="center"><strong>Envío de Documentos por vencer </strong></h1> 

{% endblock %}