{% extends "base.html" %}
{% block title %}Principal{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}
{% block modulestyle_css %}
{% endblock %}
<!-- JavaScript Code -->
{% block js_code %}{% endblock %}
{% block selected_module %} Microsip {% endblock %}
{% block breadcrumb %}
  <li><a href="/sms/">SMS</a></li> 
{% endblock %}

{% block tools-module %}
<li class="dropdown">
	<a id="drop1" href="#" role="button" class="dropdown-toggle" data-toggle="dropdown"> <i class="glyphicon glyphicon-usd"></i> <span for="" class="hidden-sm">Envío de Saldos</span>  <b class="caret"></b></a>
	<ul class="dropdown-menu" role="menu" aria-labelledby="drop1">
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/saldos/todos"><i class="glyphicon glyphicon-align-justify"></i> A Todos los Clientes</a></li>
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/saldos/por_seleccion"><i class="glyphicon glyphicon-tasks"></i> A Clientes Especificos</a></li>
<!-- 		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/saldos/todos_automatico_preferencias/"><i class="glyphicon glyphicon-time"></i> A Todos los Clientes Automático</a></li>
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/saldos/por_vencer_automatico_preferencias/"><i class="glyphicon glyphicon-time"></i> Cargos por Vencer Automático</a></li> -->
	</ul>
</li>
<li class="dropdown">
	<a id="drop1" href="#" role="button" class="dropdown-toggle" data-toggle="dropdown"> <i class="glyphicon glyphicon-pencil"></i> <span for="" class="hidden-sm">
Envío Personalizado</span> <b class="caret"></b></a>
	<ul class="dropdown-menu" role="menu" aria-labelledby="drop1">
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/personalizados/todos"><i class="glyphicon glyphicon-align-justify"></i> A Todos los Clientes</a></li>
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/personalizados/por_zona"><i class="glyphicon glyphicon-globe"></i> Por zona</a></li>
		<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/personalizados/por_seleccion"><i class="glyphicon glyphicon-tasks"></i> A Clientes Especificos</a></li>
				
	</ul>
</li>
<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/personalizados/por_telefono"><i class="glyphicon glyphicon-earphone"></i> <span for="" class="hidden-sm">Envío de Mensajes Abiertos</span></a></li>
<li role="presentation"><a role="menuitem" tabindex="-1" href="/sms/clientes"><i class="glyphicon glyphicon-user"></i> <span for="" class="hidden-sm">Clientes</span></a></li>
{% if request.user.is_superuser %}
<li class="dropdown">
  <a id="drop1" href="#" role="button" class="dropdown-toggle" data-toggle="dropdown"> <i class="glyphicon glyphicon-cog"></i> <span for="" class="hidden-sm"> Herramientas </span> <b class="caret"></b></a>
  <ul class="dropdown-menu" role="menu" aria-labelledby="drop1">
    <li><a tabindex="-1" href="/sms/preferencias"><i class="glyphicon glyphicon-wrench"></i> Preferencias </a></li>  
    <li class="bg-danger"><a tabindex="-1" href="/sms/inicializar/"><i class="glyphicon glyphicon-refresh"></i> Actualizar base de datos</a></li>
  </ul>
</li>
{% endif %}
{% endblock %}
{% block content %}

{% endblock %}