{% extends "django_msp_sms\base.html" %}
{% block title %}SMS Masivo{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}

<!-- JavaScript Code -->
{% block js_code %}
<script src="{{STATIC_URL}}js/django_msp_sms/enviar.js"></script>
{% endblock %}

{% block breadcrumb %}{{ block.super }} 
  <li class='active'> Saldos a Todos los Clientes</li>{% endblock %}
{% block content %}
<div >
	<h3><b>Envío de Saldos a Todos los Clientes {{mensaje}} </b></h3>
	<p class="text-info col-md-6 col-xs-12 cl-sm-12">
		Al pulsar el boton enviar se comenzara a enviar un mensaje por cada cliente que cuente con un saldo que a la fecha sea mayor al monto minimo <small>(especificado en las preferencias)</small> <strong> a los clientes que no cuenten con teléfono celular válido registrado en <strong><u>Teléfono 1</u> no se les enviara mensaje alguno. </strong>
	</p>
	<br style="clear:both;">
	<div id="alert_danger" class="alert alert-danger fade in" role="alert">
		<button type="button" class="close" data-dismiss="alert"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
		<div id="alert_hijo"></div>
	</div>
	<div class="progress">
	  <div id="progreso" class="progress-bar progress-bar-striped active"  role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0%">
	  </div>
	</div>
	
	<a href="#" class="btn btn-default" data-toggle="modal" data-target=".bs-example-modal-sm" >
  		Enviar
		</a>
		<div class="modal fade bs-example-modal-sm" tabindex="-1" role="dialog" aria-labelledby="mySmallModalLabel" aria-hidden="true">
		  <div class="modal-dialog modal-sm">
		    <div class="modal-content">
		      <div class="modal-header">
          		<button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">×</span><span class="sr-only">Close</span></button>
          		<h4 class="modal-title" id="mySmallModalLabel">Seguro que quieres enviar los mensajes?</h4>
        	  </div>
        	  <div class="modal-body">
        	  	<button type="button" class="btn btn-default" data-dismiss="modal">Cancelar</button>
				<a href="#" class="btn btn-default" id="enviar" data-dismiss="modal">Si, estoy seguro</a>
        	  </div>
		    </div>
		  </div>
		</div>

</div>
{% endblock %}